static char *handle[] = {
  "94 10 3 1",
  ". c none",
  "X c #ffffff",
  "o c #303030",
  "oo..oo..oo..oo..oo..oo..oo..oo..oo..oo..oo..oo..oo..oo..oo..oo..oo..oo..oo..oo..oo..oo..oo..oo",
  "oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX",
  "oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX",
  "oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX",
  "oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX",
  "oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX",
  "oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX",
  "oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX",
  "oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX",
  "XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX"
};
